Tablate is highly flexible ASCII/HTML table generator supporting a wide range of styling and input options. 
Tablate can be used in applications, IPython (Jupyter, Co-Lab, etc) or anywhere else that Python may exist.

<img src="https://tablate.readthedocs.io/en/latest/_images/basic_usage.png" alt="basic_usage">

Please check out the <a href="https://tablate.readthedocs.io/en/latest">documentation</a> for more information.